@@ -27,9 +27,9 @@
 #include <keduvocdocument.h>
 #include <sharedkvtmlfiles.h>
 
-#include <KDE/KLocale>
+#include <KLocalizedString>
 
-#include <QtGui/QApplication>
+#include <QApplication>
 
 KHangManEngine::KHangManEngine()
     : m_randomInt(0)
@@ -54,9 +54,9 @@ bool KHangManEngine::hasSpecialChars(const QString& languageCode)
             || languageCode == QLatin1String("uk")
             || languageCode == QLatin1String("el")
             || languageCode == QLatin1String("ro"))
-    {   
+    {
         return false;
-    }   
+    }
     return true;
 }
 
@@ -66,9 +66,9 @@ bool KHangManEngine::hasAccentedLetters(const QString& languageCode)
             || languageCode == QLatin1String("ca")
             || languageCode == QLatin1String("pt")
             || languageCode == QLatin1String("pt_BR"))
-    {   
+    {
         return true;
-    }   
+    }
     return false;
 }
 
@@ -80,7 +80,7 @@ void KHangManEngine::loadVocabularies()
 
     if (levelFilenames.size() == 0) {
         Prefs::setSelectedLanguage("en");
-        Prefs::self()->writeConfig();
+        Prefs::self()->save();
         levelFilenames = SharedKvtmlFiles::fileNames(Prefs::selectedLanguage());
         titles = SharedKvtmlFiles::titles(Prefs::selectedLanguage());
     }
@@ -97,7 +97,7 @@ void KHangManEngine::loadVocabularies()
     if (!levelFilenames.contains(Prefs::levelFile())) {
         Prefs::setLevelFile(m_titleLevels.constBegin().value());
         Prefs::setCurrentLevel(0);
-        Prefs::self()->writeConfig();
+        Prefs::self()->save();
     }
 
     readFile();
@@ -129,8 +129,8 @@ void KHangManEngine::readFile()
         }
 
         if (!entry->translation(0)->text().isEmpty()) {
-            m_randomList.append(qMakePair(entry->translation(0)->text(), hint));  
-        }   
+            m_randomList.append(qMakePair(entry->translation(0)->text(), hint));
+        }
     }
 
     // Shuffle the list
@@ -144,9 +144,9 @@ QString KHangManEngine::stripAccents(const QString &original)
 
     QString decomposed = original.normalized(QString::NormalizationForm_D);
     foreach (const QChar &ch, decomposed) {
-        if ( ch.category() != QChar::Mark_NonSpacing ) { 
+        if ( ch.category() != QChar::Mark_NonSpacing ) {
             noAccents.append(ch);
-        }   
+        }
     }
 
     return noAccents;
